@@ -12,44 +12,12 @@
  *
  */
 
-#include "config.h"
-
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <strings.h>
-#include <stdio.h>
-
-#include <glib.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-#include <glib/gprintf.h>
-#include <glib/gi18n.h>
-#if HAVE_GTK3 == 0
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
-#else
-#include <gio/gio.h>
-#include <gdk/gdkkeysyms-compat.h>
-#endif
-#include <libgen.h>
-#include <libmtp.h>
-#include <id3tag.h>
+#include "about.h"
 
 #include "main.h"
-#include "callbacks.h"
-#include "interface.h"
-#include "mtp.h"
-#include "prefs.h"
-#include "dnd.h"
 
 // ************************************************************************************************
 
-/**
- * Display the About Dialog Box.
- */
 void displayAbout(void) {
 
 #if GTK_CHECK_VERSION(2,12,0)
@@ -73,13 +41,13 @@ void displayAbout(void) {
     gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(dialog), PACKAGE_NAME);
     gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), PACKAGE_VERSION);
     gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog),
-            "Copyright 2009-2015, Darran Kartaschew\nReleased under the BSD License");
+            "Copyright 2009-2016, Darran Kartaschew\nReleased under the BSD License");
     gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog),
             _("A simple MTP Client for Solaris 10\nand other UNIX / UNIX-like systems\n"));
     gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(dialog),
             "gMTP License\n"
             "------------\n\n"
-            "Copyright (C) 2009-2015, Darran Kartaschew.\n"
+            "Copyright (C) 2009-2016, Darran Kartaschew.\n"
             "All rights reserved.\n\n"
             "Redistribution and use in source and binary forms, with or without "
             "modification, are permitted provided that the following conditions are met:\n\n"
@@ -107,6 +75,9 @@ void displayAbout(void) {
     gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(dialog), gdk_pixbuf_new_from_file(file_logo_png, NULL));
     gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(dialog), authors);
     gtk_about_dialog_set_translator_credits(GTK_ABOUT_DIALOG(dialog), _("translator-credits"));
+#if HAVE_GTK3 == 1
+    gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(windowMain));
+#endif
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
 #else
@@ -120,6 +91,7 @@ void displayAbout(void) {
             NULL);
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_CLOSE);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+    gtk_container_set_border_width(GTK_CONTAINER(dialog), 5);
 
 #if HAVE_GTK3 == 0
     gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
@@ -160,7 +132,7 @@ void displayAbout(void) {
     gtk_widget_show(label5);
     gtk_container_add(GTK_CONTAINER(vbox), label5);
 
-    label3 = gtk_label_new(_("<small>Copyright 2009-2014, Darran Kartaschew</small>\n<small>Released under the BSD License</small>"));
+    label3 = gtk_label_new(_("<small>Copyright 2009-2016, Darran Kartaschew</small>\n<small>Released under the BSD License</small>"));
     gtk_label_set_use_markup(GTK_LABEL(label3), TRUE);
     gtk_widget_show(label3);
     gtk_container_add(GTK_CONTAINER(vbox), label3);
